# Policy, Organisation & Rules

The ***por*** project aims to automatically generate 
the Scouts' *[Policy, Organisation and Rules](https://scouts.org.uk/por)*. 

## Notice

This is ***not*** an official resource, but a prototype of automatically 
generating POR.

## Where to get it

The source code for the project is hosted on GitHub at 
[the-scouts/por](https://github.com/the-scouts/por)

## Dependencies

- [requests](https://github.com/psf/requests) - for intuitive HTTP requests
- [lxml](https://lxml.de/) - for parsing HTML documents
- [Sphinx](https://github.com/sphinx-doc/sphinx/) - for rendering text 

## License

***por*** is naturally 
[open source](https://github.com/the-scouts/por) and is 
licensed under the **[MIT license](https://choosealicense.com/licenses/mit/)**.

The copyright of Policy, Organisation and Rules remains with The Scout Association.
